/*This programme is designed for collecting the sensor data, and can be used with PLX-DAQ. 
It has a fixed maximum sensor value, therefore the calibration only records the sensor baseline/minimum

By Amy Chen 2021
*/

#include "Adafruit_FreeTouch.h"

unsigned long previousMillis = 0;        // will store last time LED was updated
const long interval = 60000;           // interval at which to blink (milliseconds)

//Change A0 to whichever pin you are using as the sensor 
Adafruit_FreeTouch qt_1 = Adafruit_FreeTouch(A0, OVERSAMPLE_4, RESISTOR_50K, FREQ_MODE_NONE);  

int i = 0;
int sensorBase1 = 1025;           // Value used in calibration
int sensorMax1 = 1016;           // Value used in calibration (fixed)
int range1 = 0;
int thhover1 = 0;
int thtouch1 = 0;
int thgrab1 = 0;

//these are the thresholds for each gesture: over 16%, over 37% and over 98% for each respective gesture
float hover = 0.16;
float touch = 0.37;
float grab = 0.98;


void setup() {

  Serial.begin(9600);

//This is if you want to run PLXDAQ for collecting the sensor readings into a spreadsheet

  Serial.println("CLEARSHEET"); // clears sheet starting at row 1
  Serial.println("LABEL,Date,Time,Sensor,Reading,Interaction");
  // set the names for the 3 checkboxes
  Serial.println("CUSTOMBOX1,LABEL,Label1");
  Serial.println("CUSTOMBOX2,LABEL,Label2");
  Serial.println("CUSTOMBOX3,LABEL,Label3?");
  // check 2 of the 3 checkboxes (first two to true, third to false)
  Serial.println("CUSTOMBOX1,SET,0");
  Serial.println("CUSTOMBOX2,SET,0");
  Serial.println("CUSTOMBOX3,SET,0");

  while (!Serial);
  Serial.println("FreeTouch test");
  if (! qt_1.begin())
    Serial.println("Failed to begin qt on pin A0");

//Calibration phase, determining the sensor baseline (min), and the gesture sensing thresholds


  while (millis() < 10000) {
    int MeasurementsToAverage = 50;
    float sensorValue1 = 0;
    for (int i = 0; i < MeasurementsToAverage; ++i)
    {
      sensorValue1 += qt_1.measure();
      delay(1);
    }
    
    sensorValue1 /= MeasurementsToAverage;
    // record the maximum sensor 
    if (sensorValue1 < sensorBase1) {
      sensorBase1 = sensorValue1;
    }
  }
  
  Serial.print("Sensor Max");
  Serial.print(":");
  Serial.print(sensorMax1);
  Serial.println(",");

  Serial.print("Sensor Base");
  Serial.print(":");
  Serial.print(sensorBase1);
  Serial.println(",");

  range1 = sensorMax1 - sensorBase1;
  thhover1 = sensorBase1 + (range1 * hover);
  thtouch1 = sensorBase1 + (range1 * touch);
  thgrab1 = sensorBase1 + (range1 * grab);

  Serial.print("range1");
  Serial.print(":");
  Serial.print(range1);
  Serial.println("");

  Serial.print("thhover1");
  Serial.print(":");
  Serial.print(thhover1);
  Serial.println("");

  Serial.print("thtouch1");
  Serial.print(":");
  Serial.print(thtouch1);
  Serial.println("");

  Serial.print("thCover1");
  Serial.print(":");
  Serial.print(thgrab1);
  Serial.println(",");

}

void loop() {

  range1 = sensorMax1 - sensorBase1;
  thhover1 = sensorBase1 + (range1 * hover);
  thtouch1 = sensorBase1 + (range1 * touch);
  thgrab1 = sensorBase1 + (range1 * grab);
 
  //Sensor noise reduction through averaging
  int MeasurementsToAverage = 50;
  float Average1 = 0;
  for (int i = 0; i < MeasurementsToAverage; ++i)
  {
    Average1 += qt_1.measure();
    delay(1);
  }
  Average1 /= MeasurementsToAverage;


  if (Average1 > thhover1 && Average1 < thtouch1) {
    Serial.println( (String) "DATA,DATE,TIME," + "Sensor 1" + "," + Average1 + "," "Hover" + ",AUTOSCROLL_20" );
  }


  if (Average1 > thtouch1 && Average1 < thgrab1) {
    Serial.println( (String) "DATA,DATE,TIME," + "Sensor 1" + "," + Average1 + "," "Touch" + ",AUTOSCROLL_20" );
  }


  if (Average1 > thgrab1) {
    Serial.println( (String) "DATA,DATE,TIME," + "Sensor 1" + "," + Average1 + "," "Cover" + ",AUTOSCROLL_20" );
  }

  unsigned long currentMillis = millis();


  delay(100);

}
